#ifdef GL_ES
	precision mediump float;
#endif

varying vec2 v_texCoords;
varying vec4 v_color;

//declare uniforms
uniform sampler2D sceneTex;
uniform float resolution;
uniform float radius;
uniform vec2 xyOffset;

void main() {
	
    vec2 a_texcoord = vec2(v_texCoords.s, 1.0 - v_texCoords.t); 
	
    //this will be our RGBA sum
    vec4 sum = vec4(0.0);
    
    //our original texcoord for this fragment
    vec2 tc = a_texcoord;
    
    //the amount to blur, i.e. how far off center to sample from 
    //1.0 -> blur by one pixel
    //2.0 -> blur by two pixels, etc.
    float blur = radius/resolution; 
    
    //the direction of our blur
    //(1.0, 0.0) -> x-axis blur
    //(0.0, 1.0) -> y-axis blur
    float hstep = xyOffset.x;
    float vstep = xyOffset.y;
    
    
    //apply blurring, using a 9-tap filter with predefined gaussian weights
    
    sum += texture2D(sceneTex, vec2(tc.x - 4.0*blur*hstep, tc.y - 4.0*blur*vstep)) * 0.0162162162;
    sum += texture2D(sceneTex, vec2(tc.x - 3.0*blur*hstep, tc.y - 3.0*blur*vstep)) * 0.0540540541;
    sum += texture2D(sceneTex, vec2(tc.x - 2.0*blur*hstep, tc.y - 2.0*blur*vstep)) * 0.1216216216;
    sum += texture2D(sceneTex, vec2(tc.x - 1.0*blur*hstep, tc.y - 1.0*blur*vstep)) * 0.1945945946;
    
    sum += texture2D(sceneTex, vec2(tc.x, tc.y)) * 0.2270270270;
    
    sum += texture2D(sceneTex, vec2(tc.x + 1.0*blur*hstep, tc.y + 1.0*blur*vstep)) * 0.1945945946;
    sum += texture2D(sceneTex, vec2(tc.x + 2.0*blur*hstep, tc.y + 2.0*blur*vstep)) * 0.1216216216;
    sum += texture2D(sceneTex, vec2(tc.x + 3.0*blur*hstep, tc.y + 3.0*blur*vstep)) * 0.0540540541;
    sum += texture2D(sceneTex, vec2(tc.x + 4.0*blur*hstep, tc.y + 4.0*blur*vstep)) * 0.0162162162;

    //discard alpha for our simple demo, multiply by vertex color and return
    gl_FragColor =  vec4(sum.rgb, 1.0);
}